@@ -22,7 +22,7 @@ package img_test
 
 import (
 	"bytes"
-	"os"
+	"io"
 	"strings"
 
 	. "github.com/onsi/ginkgo/v2"
@@ -34,47 +34,32 @@ import (
 
 var _ = Describe("Creating images", func() {
 	Context("Use scaffold to create PNG file", func() {
-		var withTempFile = func(f func(name string)) {
-			SetColorSettings(ON, ON)
-			defer SetColorSettings(AUTO, AUTO)
+		It("should write a PNG stream based on provided input", func() {
+			scaffold := NewImageCreator()
 
-			file, err := os.CreateTemp("", "termshot.png")
+			err := scaffold.AddContent(strings.NewReader("foobar"))
 			Expect(err).ToNot(HaveOccurred())
-			defer os.Remove(file.Name())
 
-			f(file.Name())
-		}
-
-		It("should create a PNG file based on provided input", func() {
-			withTempFile(func(name string) {
-				scaffold := NewImageCreator()
-
-				err := scaffold.AddContent(strings.NewReader("foobar"))
-				Expect(err).ToNot(HaveOccurred())
-
-				err = scaffold.SavePNG(name)
-				Expect(err).ToNot(HaveOccurred())
-			})
+			err = scaffold.Write(io.Discard)
+			Expect(err).ToNot(HaveOccurred())
 		})
 
-		It("should create a PNG file based on provided input with ANSI sequences", func() {
-			withTempFile(func(name string) {
-				var buf bytes.Buffer
-				_, _ = Fprintf(&buf, "Text with emphasis, like *bold*, _italic_, _*bold/italic*_ or ~underline~.\n\n")
-				_, _ = Fprintf(&buf, "Colors:\n")
-				_, _ = Fprintf(&buf, "\tRed{Red}\n")
-				_, _ = Fprintf(&buf, "\tGreen{Green}\n")
-				_, _ = Fprintf(&buf, "\tBlue{Blue}\n")
-				_, _ = Fprintf(&buf, "\tMintCream{MintCream}\n")
+		It("should write a PNG stream based on provided input with ANSI sequences", func() {
+			var buf bytes.Buffer
+			_, _ = Fprintf(&buf, "Text with emphasis, like *bold*, _italic_, _*bold/italic*_ or ~underline~.\n\n")
+			_, _ = Fprintf(&buf, "Colors:\n")
+			_, _ = Fprintf(&buf, "\tRed{Red}\n")
+			_, _ = Fprintf(&buf, "\tGreen{Green}\n")
+			_, _ = Fprintf(&buf, "\tBlue{Blue}\n")
+			_, _ = Fprintf(&buf, "\tMintCream{MintCream}\n")
 
-				scaffold := NewImageCreator()
+			scaffold := NewImageCreator()
 
-				err := scaffold.AddContent(&buf)
-				Expect(err).ToNot(HaveOccurred())
+			err := scaffold.AddContent(&buf)
+			Expect(err).ToNot(HaveOccurred())
 
-				err = scaffold.SavePNG(name)
-				Expect(err).ToNot(HaveOccurred())
-			})
+			err = scaffold.Write(io.Discard)
+			Expect(err).ToNot(HaveOccurred())
 		})
 	})
 })
